@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 from pipes import quote
 from subprocess import Popen, PIPE
@@ -41,9 +41,9 @@ def count(author=None, period='weekly', first='monday', number=None, range='', p
 
         -a, --author=<str>  Specify an author.
         -p, --period=<str>  Specify the period: daily (d), weekly (w), monthly
-                            (m) or yearly (y). It is weekly, by default.
+                            (m) or yearly (y). Default is weekly.
         -f, --first=<str>   Specify the first day of weeks: monday (mon), sunday
-                            (sun), saturday (sat). It is monday, by default.
+                            (sun), saturday (sat). Default is monday.
         -n, --number=<int>  How many periods?
         -r, --range=<str>   Specify the range, ex. master..dev.
         -t, --paths=<str>   Specify the paths, ex. .gitignore.
@@ -71,7 +71,7 @@ def count(author=None, period='weekly', first='monday', number=None, range='', p
     elif period.startswith('m'):
         until = date(
             today.year+(today.month+1 > 12),
-            today.month+1 % 12,
+            (today.month+1) % 12,
             1
         )
         if not number: number = 12
@@ -109,33 +109,16 @@ def count(author=None, period='weekly', first='monday', number=None, range='', p
 
 def main():
 
-    clime = None
-
     try:
         import clime
     except ImportError:
-        pass
-
-    if not clime or clime.__version__ < '0.1.5':
-        print >> sys.stderr, 'It works better with Clime (>= 0.1.5). Visit http://clime.mosky.tw/ for more details.'
-
-    if clime:
-
-        if clime.__version__ < '0.2.3':
-            try:
-                # Python >= 2.6
-                from inspect import cleandoc
-            except ImportError:
-                clime.Program({'count': count}, doc=count.__doc__).main()
-            else:
-                clime.Program({'count': count}, doc=cleandoc(count.__doc__)).main()
-        else:
-            clime.start({'count': count})
+        clime = None
 
+    if clime and clime.__version__ >= '0.2':
+        clime.start({'count': count})
     else:
-
         import sys
-
+        print >> sys.stderr, 'It works better with Clime (>= 0.2). Visit http://clime.mosky.tw/ for more details.'
         if len(sys.argv) <= 1:
             count()
         else:
